@@ -5,13 +5,13 @@
 #' @export
 #' @param formula Formula for RW1 part of the model. Only right-hand-side is used. 
 #' @param data Optional data.frame.
-#' @param beta_prior A length vector of length two which defines the 
+#' @param beta A length vector of length two which defines the 
 #' prior mean and standard deviation of the Gaussian prior for coefficients at time 1.
-#' @param sigma_prior A vector of length two, defining the truncated Gaussian prior for 
+#' @param sigma A vector of length two, defining the truncated Gaussian prior for 
 #' the coefficient level standard deviation. 
 #' @param gamma An optional vector defining a damping of the random walk noises. More specifically, 
 #' the variance of the conditional distribution of state_t+1 given state is of form gamma_t * sigma.
-rw1 <- function(formula, data, beta_prior, sigma_prior, gamma = NULL) {
+rw1 <- function(formula, data, beta, sigma, gamma = NULL) {
  
   mf <- match.call(expand.dots = FALSE)
   mf <- mf[c(1L, match(c("formula", "data"), names(mf), 0L))]
@@ -21,11 +21,11 @@ rw1 <- function(formula, data, beta_prior, sigma_prior, gamma = NULL) {
   mf <- eval(mf, parent.frame())
   xreg <- model.matrix(attr(mf, "terms"), mf)
   
-  if(length(beta_prior) != 2) {
-    stop("beta_prior should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of coefficients. ")
+  if(length(beta) != 2) {
+    stop("beta should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of coefficients. ")
   }
-  if(length(sigma_prior) != 2) {
-    stop("sigma_prior should be should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of standard deviations. ")
+  if(length(sigma) != 2) {
+    stop("sigma should be should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of standard deviations. ")
   }
   n <- nrow(xreg)
   if (is.null(gamma)) {
@@ -36,8 +36,8 @@ rw1 <- function(formula, data, beta_prior, sigma_prior, gamma = NULL) {
     if (!is.numeric(gamma) | any(gamma < 0 | is.na(gamma))) 
       stop("Argument 'gamma' should be numeric matrix of nonnegative values. ")
   } 
-  list(xreg = xreg, beta_prior = beta_prior, 
-    sigma_prior = sigma_prior, gamma = gamma)
+  list(xreg = xreg, beta = beta, 
+    sigma = sigma, gamma = gamma)
   
 }
 #' Construct a second-order random walk component 
@@ -47,16 +47,16 @@ rw1 <- function(formula, data, beta_prior, sigma_prior, gamma = NULL) {
 #' @export
 #' @param formula Formula for RW2 part of the model. Only right-hand-side is used. 
 #' @param data Optional data.frame.
-#' @param beta_prior A vector of length two which defines the 
+#' @param beta A vector of length two which defines the 
 #' prior mean and standard deviation of the Gaussian prior for coefficients at time 1.
-#' @param sigma_prior A vector of length two, defining the truncated Gaussian prior for 
+#' @param sigma A vector of length two, defining the truncated Gaussian prior for 
 #' the slope level standard deviation. 
-#' @param slope_prior A vector of length two which defines the 
-#' prior mean and standard deviation of the Gaussian prior for the slopes at time 1.
+#' @param nu A vector of length two which defines the 
+#' prior mean and standard deviation of the Gaussian prior for the slopes nu at time 1.
 #'@param gamma An optional vector defining a damping of the slope level noises. More specifically, 
 #' the variance of the conditional distribution of state_t+1 given state is of form gamma_t * sigma.
 #' @export
-rw2 <- function(formula, data, beta_prior, sigma_prior, slope_prior, gamma = NULL) {
+rw2 <- function(formula, data, beta, sigma, nu, gamma = NULL) {
   
   mf <- match.call(expand.dots = FALSE)
   mf <- mf[c(1L, match(c("formula", "data"), names(mf), 0L))]
@@ -66,14 +66,14 @@ rw2 <- function(formula, data, beta_prior, sigma_prior, slope_prior, gamma = NUL
   mf <- eval(mf, parent.frame())
   xreg <- model.matrix(attr(mf, "terms"), mf)
   
-  if(length(beta_prior) != 2) {
-    stop("beta_prior should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of initial coefficients. ")
+  if(length(beta) != 2) {
+    stop("beta should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of initial coefficients. ")
   }
-  if(length(sigma_prior) != 2) {
-    stop("sigma_prior should be should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of standard deviations. ")
+  if(length(sigma) != 2) {
+    stop("sigma should be should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of standard deviations. ")
   }
-  if(length(slope_prior) != 2) {
-    stop("slope_prior should be should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of initial slope coeffients. ")
+  if(length(nu) != 2) {
+    stop("nu should be should be a vector of length two, defining the mean and standard deviation for the Gaussian prior of initial slope coeffients. ")
   }
   n <- nrow(xreg)
   if (is.null(gamma)) {
@@ -84,7 +84,7 @@ rw2 <- function(formula, data, beta_prior, sigma_prior, slope_prior, gamma = NUL
     if (!is.numeric(gamma) | any(gamma < 0 | is.na(gamma))) 
       stop("Argument 'gamma' should be numeric matrix of nonnegative values. ")
   } 
-  list(xreg = xreg, beta_prior = beta_prior, 
-    sigma_prior = sigma_prior, slope_prior = slope_prior, gamma = gamma)
+  list(xreg = xreg, beta = beta, 
+    sigma = sigma, nu = nu, gamma = gamma)
   
 }
\ No newline at end of file
